@@ -1,6 +1,6 @@
 /*
  * nield.c - evnent receiver
- * Copyright (C) 2014 Tetsumune KISO <t2mune@gmail.com>
+ * Copyright (C) 2015 Tetsumune KISO <t2mune@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -481,8 +481,8 @@ void sigint_handler(int sig)
 void sigusr1_handler(int sig)
 {
     rec_log("info: SIGUSR1 called(PID: %ld)", (long)getpid());
-    print_iflist();
-    print_ifhist();
+    print_iflist(1);
+    print_iflist(2);
 }
 
 /*
@@ -534,17 +534,17 @@ int set_rtnetlink_groups(void)
         if(msg_opts & M_IPV4)
             groups |= RTMGRP_LINK | RTMGRP_NEIGH |
                       RTMGRP_IPV4_IFADDR | RTMGRP_IPV4_ROUTE | RTMGRP_IPV4_RULE |
-                  RTMGRP_TC;
+                      RTMGRP_TC;
         if(msg_opts & M_IPV6)
             groups |= RTMGRP_LINK | RTMGRP_NEIGH |
                       RTMGRP_IPV6_IFADDR | RTMGRP_IPV6_ROUTE | (1 << (RTNLGRP_IPV6_RULE - 1)) |
-                  RTMGRP_TC;
+                      RTMGRP_TC;
         /* receive all events if the flag is set to only L_DEBUG or none */
         if(!(msg_opts & (M_IPV4 | M_IPV6)))
             groups |= RTMGRP_LINK | RTMGRP_NEIGH | 
                       RTMGRP_IPV4_IFADDR | RTMGRP_IPV4_ROUTE | RTMGRP_IPV4_RULE |
-                  RTMGRP_IPV6_IFADDR | RTMGRP_IPV6_ROUTE | (1 << (RTNLGRP_IPV6_RULE - 1)) |
-                  RTMGRP_TC;
+                      RTMGRP_IPV6_IFADDR | RTMGRP_IPV6_ROUTE | (1 << (RTNLGRP_IPV6_RULE - 1)) |
+                      RTMGRP_TC;
     }
 
     return(groups);
@@ -843,7 +843,7 @@ int parse_events(struct msghdr *mhdr)
                 break;
             /* unknown message */
             default:
-                rec_log("error: %s: unkonwn nlsmg_type: %d",
+                rec_log("error: %s: unknown nlsmg_type: %d",
                     __func__, (int)nlh->nlmsg_type);
         }
     }
