@@ -1,6 +1,6 @@
 /*
  * rtmsg.c - route message parser
- * Copyright (C) 2014 Tetsumune KISO <t2mune@gmail.com>
+ * Copyright (C) 2015 Tetsumune KISO <t2mune@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -68,7 +68,7 @@ int parse_rtmsg(struct nlmsghdr *nlh)
 
     /* convert from table id to table name */
     char table[MAX_STR_SIZE] = "";
-    snprintf(table, sizeof(table), "%s", convert_rt_table(rtm->rtm_table, 0));
+    snprintf(table, sizeof(table), "%s", conv_rt_table(rtm->rtm_table, 0));
     if(!strncmp(table, "unknown", sizeof(table)))
         snprintf(table, sizeof(table), "%d", rtm->rtm_table);
 
@@ -181,11 +181,11 @@ int parse_rtmsg(struct nlmsghdr *nlh)
 
     /* convert route message type */
     char type[MAX_STR_SIZE] = "";
-    snprintf(type, sizeof(type), "%s", convert_rtn_type(rtm->rtm_type, 0));
+    snprintf(type, sizeof(type), "%s", conv_rtn_type(rtm->rtm_type, 0));
 
     /* convert route message protocol */
     char proto[MAX_STR_SIZE] = "";
-    snprintf(proto, sizeof(proto), "%s", convert_rtprot(rtm->rtm_protocol, 0));
+    snprintf(proto, sizeof(proto), "%s", conv_rtprot(rtm->rtm_protocol, 0));
 
     /* get table id & name */
     if(rta[RTA_TABLE]) {
@@ -195,7 +195,7 @@ int parse_rtmsg(struct nlmsghdr *nlh)
             rec_log("error: %s: RTA_TABLE: payload too short", __func__);
             return(1);
         }
-        snprintf(table, sizeof(table), "%s", convert_rt_table(table_id, 0));
+        snprintf(table, sizeof(table), "%s", conv_rt_table(table_id, 0));
         if(!strncmp(table, "unknown", sizeof(table)))
             snprintf(table, sizeof(table), "%d", table_id);
     }
@@ -264,14 +264,14 @@ void debug_rtmsg(int lev, struct rtmsg *rtm, struct rtattr *rta[], int rtm_len)
     /* debug rtmsg */
     char flags_list[MAX_STR_SIZE] = "";
 
-    convert_rtm_flags(rtm->rtm_flags, flags_list, sizeof(flags_list));
+    conv_rtm_flags(rtm->rtm_flags, flags_list, sizeof(flags_list));
 
     rec_dbg(lev, "*********************************************************************");
     rec_dbg(lev, "[ rtmsg(%d) ]",
         NLMSG_ALIGN(sizeof(struct rtmsg)));
     rec_dbg(lev, "    rtm_family(%d): %d(%s)",
         sizeof(rtm->rtm_family), rtm->rtm_family,
-        convert_af_type(rtm->rtm_family));
+        conv_af_type(rtm->rtm_family, 1));
     rec_dbg(lev, "    rtm_dst_len(%d): %d",
         sizeof(rtm->rtm_dst_len), rtm->rtm_dst_len);
     rec_dbg(lev, "    rtm_src_len(%d): %d",
@@ -280,19 +280,18 @@ void debug_rtmsg(int lev, struct rtmsg *rtm, struct rtattr *rta[], int rtm_len)
         sizeof(rtm->rtm_tos), rtm->rtm_tos);
     rec_dbg(lev, "    rtm_table(%d): %d(%s)",
         sizeof(rtm->rtm_table), rtm->rtm_table,
-        convert_rt_table(rtm->rtm_table, 1));
+        conv_rt_table(rtm->rtm_table, 1));
     rec_dbg(lev, "    rtm_protocol(%d): %d(%s)",
         sizeof(rtm->rtm_protocol), rtm->rtm_protocol,
-        convert_rtprot(rtm->rtm_protocol, 1));
+        conv_rtprot(rtm->rtm_protocol, 1));
     rec_dbg(lev, "    rtm_scope(%d): %d(%s)",
         sizeof(rtm->rtm_scope), rtm->rtm_scope,
-        convert_rt_scope(rtm->rtm_scope));
+        conv_rt_scope(rtm->rtm_scope));
     rec_dbg(lev, "    rtm_type(%d): %d(%s)",
         sizeof(rtm->rtm_type), rtm->rtm_type,
-        convert_rtn_type(rtm->rtm_type, 1));
+        conv_rtn_type(rtm->rtm_type, 1));
     rec_dbg(lev, "    rtm_flags(%d): %d(%s)",
-        sizeof(rtm->rtm_flags), rtm->rtm_flags,
-        flags_list);
+        sizeof(rtm->rtm_flags), rtm->rtm_flags, flags_list);
 
     /* debug route attributes */
     rec_dbg(lev, "*********************************************************************");
@@ -300,44 +299,57 @@ void debug_rtmsg(int lev, struct rtmsg *rtm, struct rtattr *rta[], int rtm_len)
         NLMSG_ALIGN(rtm_len - NLMSG_ALIGN(sizeof(struct rtmsg))));
 
     if(rta[RTA_DST])
-        debug_rta_dst(lev+1, rtm, rta[RTA_DST]);
+        debug_rta_af(lev+1, rta[RTA_DST],
+            "RTA_DST", rtm->rtm_family);
 
     if(rta[RTA_SRC])
-        debug_rta_src(lev+1, rtm, rta[RTA_SRC]);
+        debug_rta_af(lev+1, rta[RTA_SRC],
+            "RTA_SRC", rtm->rtm_family);
 
     if(rta[RTA_IIF])
-        debug_rta_iif(lev+1, rta[RTA_IIF]);
+        debug_rta_ifindex(lev+1, rta[RTA_IIF],
+            "RTA_IIF");
 
     if(rta[RTA_OIF])
-        debug_rta_oif(lev+1, rta[RTA_OIF]);
+        debug_rta_ifindex(lev+1, rta[RTA_OIF],
+            "RTA_OIF");
 
     if(rta[RTA_GATEWAY])
-        debug_rta_gateway(lev+1, rtm, rta[RTA_GATEWAY]);
+        debug_rta_af(lev+1, rta[RTA_GATEWAY],
+            "RTA_GATEWAY", rtm->rtm_family);
 
     if(rta[RTA_PRIORITY])
-        debug_rta_priority(lev+1, rta[RTA_PRIORITY]);
+        debug_rta_s32(lev+1, rta[RTA_PRIORITY],
+            "RTA_PRIORITY", NULL);
 
     if(rta[RTA_PREFSRC])
-        debug_rta_prefsrc(lev+1, rtm, rta[RTA_PREFSRC]);
+        debug_rta_af(lev+1, rta[RTA_PREFSRC],
+            "RTA_PREFSRC", rtm->rtm_family);
 
     if(rta[RTA_METRICS])
-        debug_rta_metrics(lev+1, rta[RTA_METRICS]);
+        debug_rta_metrics(lev+1, rta[RTA_METRICS],
+            "RTA_METRICS");
 
     if(rta[RTA_MULTIPATH])
-        debug_rta_multipath(lev+1, rtm, rta[RTA_MULTIPATH]);
+        debug_rta_multipath(lev+1, rtm, rta[RTA_MULTIPATH],
+            "RTA_MULTIPATH");
 
     if(rta[RTA_FLOW])
-        debug_rta_flow(lev+1, rta[RTA_FLOW]);
+        debug_rta_u32(lev+1, rta[RTA_FLOW],
+            "RTA_FLOW", NULL);
 
     if(rta[RTA_CACHEINFO])
-        debug_rta_cacheinfo(lev+1, rta[RTA_CACHEINFO]);
+        debug_rta_cacheinfo(lev+1, rta[RTA_CACHEINFO],
+            "RTA_CACHEINFO");
 
     if(rta[RTA_TABLE])
-        debug_rta_table(lev+1, rta[RTA_TABLE]);
+        debug_rta_s32(lev+1, rta[RTA_TABLE],
+            "RTA_TABLE", conv_rt_table);
 
 #if HAVE_DECL_RTA_MARK
     if(rta[RTA_MARK])
-        debug_rta_mark(lev+1, rta[RTA_TABLE]);
+        debug_rta_u32(lev+1, rta[RTA_MARK],
+            "RTA_MARK", NULL);
 #endif
 
     rec_dbg(lev, "");
@@ -345,240 +357,41 @@ void debug_rtmsg(int lev, struct rtmsg *rtm, struct rtattr *rta[], int rtm_len)
     return;
 }
 
-/*
- * debug attribute RTA_DST
- */
-void debug_rta_dst(int lev, struct rtmsg *rtm, struct rtattr *rta)
-{
-    char dst[INET6_ADDRSTRLEN] = "";
-    int res;
-
-    res = inet_ntop_ifa(rtm->rtm_family, rta, dst, sizeof(dst));
-    if(res) {
-        rec_dbg(lev, "RTA_DST(%hu): -- %s --",
-            RTA_ALIGN(rta->rta_len),
-            (res == 1) ? strerror(errno) : "payload too short");
-        return;
-    }
-
-    rec_dbg(lev, "RTA_DST(%hu): %s", RTA_ALIGN(rta->rta_len), dst);
-}
-
-/*
- * debug attribute RTA_SRC
- */
-void debug_rta_src(int lev, struct rtmsg *rtm, struct rtattr *rta)
-{
-    char src[INET6_ADDRSTRLEN] = "";
-    int res;
-
-    res = inet_ntop_ifa(rtm->rtm_family, rta, src, sizeof(src));
-    if(res) {
-        rec_dbg(lev, "RTA_SRC(%hu): -- %s --",
-            RTA_ALIGN(rta->rta_len),
-            (res == 1) ? strerror(errno) : "payload too short");
-        return;
-    }
-
-    rec_dbg(lev, "RTA_SRC(%hu): %s", RTA_ALIGN(rta->rta_len), src);
-}
-
-/*
- * debug attribute RTA_IIF
- */
-void debug_rta_iif(int lev, struct rtattr *rta)
-{
-    char ifname[IFNAMSIZ] = "";
-    int ifindex;
-
-    if(RTA_PAYLOAD(rta) < sizeof(ifindex)) {
-        rec_dbg(lev, "RTA_IIF(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    ifindex = *((int *)RTA_DATA(rta));
-    if_indextoname_from_lists(ifindex, ifname);
-
-    rec_dbg(lev, "RTA_IIF(%hu): %d(%s)",
-        RTA_ALIGN(rta->rta_len), ifindex, ifname);
-}
-
-/*
- * debug attribute RTA_OIF
- */
-void debug_rta_oif(int lev, struct rtattr *rta)
-{
-    char ifname[IFNAMSIZ] = "";
-    int ifindex;
-
-    if(RTA_PAYLOAD(rta) < sizeof(ifindex)) {
-        rec_dbg(lev, "RTA_OIF(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    ifindex = *((int *)RTA_DATA(rta));
-    if_indextoname_from_lists(ifindex, ifname);
-
-    rec_dbg(lev, "RTA_OIF(%hu): %d(%s)",
-        RTA_ALIGN(rta->rta_len), ifindex, ifname);
-}
-
-/*
- * debug attribute RTA_GATEWAY
- */
-void debug_rta_gateway(int lev, struct rtmsg *rtm, struct rtattr *rta)
-{
-    char nexthop[INET6_ADDRSTRLEN] = "";
-    int res;
-
-    res = inet_ntop_ifa(rtm->rtm_family, rta, nexthop, sizeof(nexthop));
-    if(res) {
-        rec_dbg(lev, "RTA_GATEWAY(%hu): -- %s --",
-            RTA_ALIGN(rta->rta_len),
-            (res == 1) ? strerror(errno) : "payload too short");
-        return;
-    }
-
-    rec_dbg(lev, "RTA_GATEWAY(%hu): %s", RTA_ALIGN(rta->rta_len), nexthop);
-}
-
-/*
- * debug attribute RTA_PRIORITY
- */
-void debug_rta_priority(int lev, struct rtattr *rta)
-{
-    int priority;
-
-    if(RTA_PAYLOAD(rta) < sizeof(priority)) {
-        rec_dbg(lev, "RTA_PRIORITY(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    priority = *((int *)RTA_DATA(rta));
-
-    rec_dbg(lev, "RTA_PRIORITY(%hu): %d", RTA_ALIGN(rta->rta_len), priority);
-}
-
-/*
- * debug attribute RTA_PREFSRC
- */
-void debug_rta_prefsrc(int lev, struct rtmsg *rtm, struct rtattr *rta)
-{
-    char prefsrc[INET6_ADDRSTRLEN] = "";
-    int res;
-
-    res = inet_ntop_ifa(rtm->rtm_family, rta, prefsrc, sizeof(prefsrc));
-    if(res) {
-        rec_dbg(lev, "RTA_PREFSRC(%hu): -- %s --",
-            RTA_ALIGN(rta->rta_len),
-            (res == 1) ? strerror(errno) : "payload too short");
-        return;
-    }
-
-    rec_dbg(lev, "RTA_PREFSRC(%hu): %s", RTA_ALIGN(rta->rta_len), prefsrc);
-}
-
 /*
  * debug attribute RTA_METRICS
  */
-void debug_rta_metrics(int lev, struct rtattr *rta)
+void debug_rta_metrics(int lev, struct rtattr *rta, const char *name)
 {
     struct rtattr *rtax[RTAX_MAX+1];
 
-    rec_dbg(lev, "RTA_METRICS(%hu):", RTA_ALIGN(rta->rta_len));
-
+    rec_dbg(lev, "%s(%hu):", name, RTA_ALIGN(rta->rta_len));
     parse_rtattr(rtax, RTAX_MAX, RTA_DATA(rta), RTA_PAYLOAD(rta));
 
     if(rtax[RTAX_LOCK])
-        debug_rtax_lock(lev+1, rtax[RTAX_LOCK]);
+        debug_rta_u32(lev+1, rtax[RTAX_LOCK],
+            "RTAX_LOCK", NULL);
 
     if(rtax[RTAX_MTU])
-        debug_rtax_mtu(lev+1, rtax[RTAX_MTU]);
+        debug_rta_u32(lev+1, rtax[RTAX_MTU],
+            "RTAX_MTU", NULL);
 
     if(rtax[RTAX_ADVMSS])
-        debug_rtax_advmss(lev+1, rtax[RTAX_ADVMSS]);
+        debug_rta_u32(lev+1, rtax[RTAX_ADVMSS],
+            "RTAX_ADVMSS", NULL);
 
     if(rtax[RTAX_HOPLIMIT])
-        debug_rtax_hoplimit(lev+1, rtax[RTAX_HOPLIMIT]);
+        debug_rta_s32(lev+1, rtax[RTAX_HOPLIMIT],
+            "RTAX_HOPLIMIT", NULL);
 
     if(rtax[RTAX_WINDOW])
-        debug_rtax_window(lev+1, rtax[RTAX_WINDOW]);
-}
-
-/*
- * debug attribute RTAX_LOCK
- */
-void debug_rtax_lock(int lev, struct rtattr *rtax)
-{
-    if(RTA_PAYLOAD(rtax) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTAX_LOCK(%hu): -- payload too short --",
-            RTA_ALIGN(rtax->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTAX_LOCK(%hu): %u",
-        RTA_ALIGN(rtax->rta_len), *(unsigned *)RTA_DATA(rtax));
-}
-
-/*
- * debug attribute RTAX_MTU
- */
-void debug_rtax_mtu(int lev, struct rtattr *rtax)
-{
-    if(RTA_PAYLOAD(rtax) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTAX_MTU(%hu): -- payload too short --",
-            RTA_ALIGN(rtax->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTAX_MTU(%hu): %u",
-        RTA_ALIGN(rtax->rta_len), *(unsigned *)RTA_DATA(rtax));
-}
-
-/*
- * debug attribute RTAX_ADVMSS
- */
-void debug_rtax_advmss(int lev, struct rtattr *rtax)
-{
-    if(RTA_PAYLOAD(rtax) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTAX_ADVMSS(%hu): -- payload too short --",
-            RTA_ALIGN(rtax->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTAX_ADVMSS(%hu): %u",
-        RTA_ALIGN(rtax->rta_len), *(unsigned *)RTA_DATA(rtax));
-}
-
-/*
- * debug attribute RTAX_HOPLIMIT
- */
-void debug_rtax_hoplimit(int lev, struct rtattr *rtax)
-{
-    if(RTA_PAYLOAD(rtax) < sizeof(int)) {
-        rec_dbg(lev, "RTAX_HOPLIMIT(%hu): -- payload too short --",
-            RTA_ALIGN(rtax->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTAX_HOPLIMIT(%hu): %d",
-        RTA_ALIGN(rtax->rta_len), *(int *)RTA_DATA(rtax));
-}
-
-/*
- * debug attribute RTAX_WINDOW
- */
-void debug_rtax_window(int lev, struct rtattr *rtax)
-{
-    if(RTA_PAYLOAD(rtax) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTAX_WINDOW(%hu): -- payload too short --",
-            RTA_ALIGN(rtax->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTAX_WINDOW(%hu): %u",
-        RTA_ALIGN(rtax->rta_len), *(unsigned *)RTA_DATA(rtax));
+        debug_rta_u32(lev+1, rtax[RTAX_WINDOW],
+            "RTAX_WINDOW", NULL);
 }
 
 /*
  * debug attribute RTA_MULTIPATH
  */
-void debug_rta_multipath(int lev, struct rtmsg *rtm, struct rtattr *rta)
+void debug_rta_multipath(int lev, struct rtmsg *rtm, struct rtattr *rta, const char *name)
 {
     struct rtnexthop *rtnh;
     int rtnh_len = RTA_PAYLOAD(rta);
@@ -586,18 +399,14 @@ void debug_rta_multipath(int lev, struct rtmsg *rtm, struct rtattr *rta)
     char ifname[IFNAMSIZ] = "";
     char flags_list[MAX_STR_SIZE] = "";
 
-    if(RTA_PAYLOAD(rta) < sizeof(*rtnh)) {
-        rec_dbg(lev, "RTA_MULTIPATH(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
+    if(debug_rta_len_chk(lev, rta, name, sizeof(*rtnh)))
         return;
-    }
-    rtnh = RTA_DATA(rta);
 
-    rec_dbg(lev, "RTA_MULTIPATH(%hu):", RTA_ALIGN(rta->rta_len));
+    rec_dbg(lev, "%s(%hu):", name, RTA_ALIGN(rta->rta_len));
 
-    for(; RTNH_OK(rtnh, rtnh_len);
+    for(rtnh = RTA_DATA(rta); RTNH_OK(rtnh, rtnh_len);
         rtnh = RTNH_NEXT(rtnh), rtnh_len -= RTNH_ALIGN(rtnh->rtnh_len)) {
-        convert_rtnh_flags(rtnh->rtnh_flags, flags_list, sizeof(flags_list));
+        conv_rtnh_flags(rtnh->rtnh_flags, flags_list, sizeof(flags_list));
         if_indextoname_from_lists(rtnh->rtnh_ifindex, ifname);
 
         rec_dbg(lev, "    [ rtnexthop(%d) ]", sizeof(*rtnh));
@@ -613,39 +422,23 @@ void debug_rta_multipath(int lev, struct rtmsg *rtm, struct rtattr *rta)
         parse_rtattr(rtnha, RTA_MAX, RTNH_DATA(rtnh), rtnh->rtnh_len - sizeof(*rtnh));
 
         if(rtnha[RTA_GATEWAY])
-            debug_rta_gateway(lev+3, rtm, rtnha[RTA_GATEWAY]);
+            debug_rta_af(lev+3, rtnha[RTA_GATEWAY], "RTA_GATEWAY", rtm->rtm_family);
     }
 }
 
-/*
- * debug attribute RTA_FLOW
- */
-void debug_rta_flow(int lev, struct rtattr *rta)
-{
-    if(RTA_PAYLOAD(rta) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTA_FLOW(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTA_FLOW(%hu): %u",
-        RTA_ALIGN(rta->rta_len), *((unsigned *)RTA_DATA(rta)));
-}
-
 /*
  * debug attribute RTA_CACHEINFO
  */
-void debug_rta_cacheinfo(int lev, struct rtattr *rta)
+void debug_rta_cacheinfo(int lev, struct rtattr *rta, const char *name)
 {
     struct rta_cacheinfo *rtac;
 
-    if(RTA_PAYLOAD(rta) < sizeof(*rtac)) {
-        rec_dbg(lev, "RTA_CACHEINFO(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
+    if(debug_rta_len_chk(lev, rta, name, sizeof(*rtac)))
         return;
-    }
+
     rtac = (struct rta_cacheinfo *)RTA_DATA(rta);
 
-    rec_dbg(lev, "RTA_CACHEINFO(%hu):", RTA_ALIGN(rta->rta_len));
+    rec_dbg(lev, "%s(%hu):", name, RTA_ALIGN(rta->rta_len));
     rec_dbg(lev, "    [ rta_cacheinfo(%d) ]", sizeof(*rtac));
     rec_dbg(lev, "        rta_clntref(%d): %u",
         sizeof(rtac->rta_clntref), rtac->rta_clntref);
@@ -665,41 +458,10 @@ void debug_rta_cacheinfo(int lev, struct rtattr *rta)
         sizeof(rtac->rta_tsage), rtac->rta_tsage);
 }
 
-/*
- * debug attribute RTA_TABLE
- */
-void debug_rta_table(int lev, struct rtattr *rta)
-{
-    if(RTA_PAYLOAD(rta) < sizeof(int)) {
-        rec_dbg(lev, "RTA_TABLE(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTA_TABLE(%hu): %d(%s)",
-        RTA_ALIGN(rta->rta_len), *(int *)RTA_DATA(rta),
-        convert_rt_table(*(int *)RTA_DATA(rta), 1));
-}
-
-#if HAVE_DECL_RTA_MARK
-/*
- * debug attribute RTA_MARK
- */
-void debug_rta_mark(int lev, struct rtattr *rta)
-{
-    if(RTA_PAYLOAD(rta) < sizeof(unsigned)) {
-        rec_dbg(lev, "RTA_MARK(%hu): -- payload too short --",
-            RTA_ALIGN(rta->rta_len));
-        return;
-    }
-    rec_dbg(lev, "RTA_MARK(%hu): %u",
-        RTA_ALIGN(rta->rta_len), *(unsigned *)RTA_DATA(rta));
-}
-#endif
-
 /*
  * convert rtm_table from number to string
  */
-const char *convert_rt_table(int table, int debug)
+const char *conv_rt_table(int table, unsigned char debug)
 {
 #define _RT_TABLE(s1, s2) \
     if(table == RT_TABLE_##s1) \
@@ -718,7 +480,7 @@ const char *convert_rt_table(int table, int debug)
 /*
  * convert rtm_protocol from number to string
  */
-const char *convert_rtprot(int protocol, int debug)
+const char *conv_rtprot(int protocol, unsigned char debug)
 {
 #define _RTM_PROTOCOL(s1, s2) \
     if(protocol == RTPROT_##s1) \
@@ -746,7 +508,7 @@ const char *convert_rtprot(int protocol, int debug)
 /*
  * convert rtm_scope from number to string
  */
-const char *convert_rt_scope(int scope)
+const char *conv_rt_scope(int scope)
 {
 #define _RT_SCOPE(s) \
     if(scope == RT_SCOPE_##s) \
@@ -763,7 +525,7 @@ const char *convert_rt_scope(int scope)
 /*
  * convert rtm_type from number to string
  */
-const char *convert_rtn_type(int type, int debug)
+const char *conv_rtn_type(int type, unsigned char debug)
 {
 #define _RTN_TYPE(s1, s2) \
     if(type == RTN_##s1) \
@@ -787,7 +549,7 @@ const char *convert_rtn_type(int type, int debug)
 /*
  * convert rtm_flags from number to string
  */
-void convert_rtm_flags(int flags, char *flags_list, int len)
+void conv_rtm_flags(int flags, char *flags_list, int len)
 {
     if(!flags) {
         strncpy(flags_list, "NONE", len);
@@ -810,7 +572,7 @@ void convert_rtm_flags(int flags, char *flags_list, int len)
 /*
  * convert rtnh_flags from number to string
  */
-void convert_rtnh_flags(int flags, char *flags_list, int len)
+void conv_rtnh_flags(int flags, char *flags_list, int len)
 {
     if(!flags) {
         strncpy(flags_list, "NONE", len);
